API Reference
=============

Forms
-----

.. autoclass:: pyramid_uniform.State
    :members:


.. autoclass:: pyramid_uniform.Form
    :members:
    :undoc-members:


Rendering
---------


.. autoclass:: pyramid_uniform.Renderer
    :members:
    :undoc-members:


.. autoclass:: pyramid_uniform.FormRenderer
    :members:
    :undoc-members:
    :show-inheritance:


Exceptions
----------

.. autoexception:: pyramid_uniform.FormError
    :show-inheritance:


.. autoexception:: pyramid_uniform.FormInvalid
    :show-inheritance:


.. autoexception:: pyramid_uniform.FormNotValidated
    :show-inheritance:
